@@ -26,13 +26,16 @@ from apigee.configure.commands import configure
 from apigee.deployments.commands import deployments
 from apigee.developers.commands import developers
 from apigee.exceptions import exception_handler
+from apigee.keystores.commands import keystores
 from apigee.keyvaluemaps.commands import keyvaluemaps
 from apigee.maskconfigs.commands import maskconfigs
 from apigee.permissions.commands import permissions
+from apigee.references.commands import references
 from apigee.sharedflows.commands import sharedflows
 from apigee.targetservers.commands import targetservers
 from apigee.userroles.commands import userroles
 from apigee.utils import show_message
+from apigee.virtualhosts.commands import virtualhosts
 
 # from click_aliases import ClickAliasedGroup
 
@@ -79,6 +82,9 @@ def main():
         userroles,
         permissions,
         sharedflows,
+        keystores,
+        references,
+        virtualhosts,
     ]
 
     if os.path.exists(APIGEE_CLI_PLUGINS_PATH):
